module top(
  input Reset,
  output [7:0] Cathodes,
  output [7:0] Segments
);

  // Generator sygnau zegarowego
  wire Clock14MHz;
  OSCH #(
    .NOM_FREQ("14.00")
  ) OSCH_inst(
    .STDBY(1'b0),
    .OSC(Clock14MHz),
    .SEDSTDBY()
  );
  
  // Licznik Data ma by zwikszany co 0,1s
  wire CountEnable;
  StrobeGenerator #(
    .FREQUENCY_HZ(14000000),
    .PERIOD_US(100000)
  ) CountStrobeGenerator(
    .Clock(Clock14MHz),
    .Reset(Reset),
    .Strobe(CountEnable)
  );
  
  // Stan tego licznika zostanie pokazany na wywietlaczu
  reg [31:0] Data;
  always @(posedge Clock14MHz, negedge Reset)
    if(!Reset)
      Data = 32'hFF;
    else if(CountEnable)
      Data <= Data + 1'b1;
  
  // Przecinki maj by przesuwane co 1s
  wire DecimalPointMoveEnable;
  StrobeGenerator #(
    .FREQUENCY_HZ(14000000),
    .PERIOD_US(1000000)
  ) DecimalStrobeGenerator(
    .Clock(Clock14MHz),
    .Reset(Reset),
    .Strobe(DecimalPointMoveEnable)
  );
  
  // Kod odpowiedzialny za przesuwanie przecinkw
  reg [7:0] DecimalPoints;
  always @(posedge Clock14MHz, negedge Reset)
    if(!Reset)
      DecimalPoints = 8'b00000011;
    else if(DecimalPointMoveEnable)
      DecimalPoints <= {DecimalPoints[6:0], DecimalPoints[7]};
    
  // Instancja wywietlacza multipleksowanego
  DisplayMultiplex #(
    .FREQUENCY_HZ(14000000),
    .SWITCH_PERIOD_US(1000) // max 2000
  ) DisplayMultiplex0(
    .Clock(Clock14MHz),
    .Reset(Reset),
    .Data(Data),
    .DecimalPoints(DecimalPoints),
    .Cathodes(Cathodes),
    .Segments(Segments)
  );

endmodule
